@@ -7,7 +7,6 @@ Created on Mon Sep 21 11:21:23 2020
 
 import nidaqmx
 from nidaqmx.constants import TerminalConfiguration
-from instrumental import u
 import numpy as np
 '''Needs to be rewritten in class structure'''
 
@@ -15,8 +14,12 @@ import numpy as np
 
 def Photodiode():
     with nidaqmx.Task() as task:
-        ai_channel = task.ai_channels.add_ai_voltage_chan("Dev1/ai0",terminal_config = TerminalConfiguration.RSE)
+        ai_channel = task.ai_channels.add_ai_voltage_chan("Dev1/ai1")
         r = task.read(number_of_samples_per_channel=100)
         m = np.mean(r)
         delta = np.std(r)
-        return m, delta
\ No newline at end of file
+        return m, delta
+
+
+if __name__=='__main__':
+    Photodiode()
\ No newline at end of file
